Installation
============

Basic
-----

.. code-block:: bash

   pip install scitex-app

CLI support
-----------

.. code-block:: bash

   pip install scitex-app[cli]

MCP support
-----------

.. code-block:: bash

   pip install scitex-app[mcp]

All features
------------

.. code-block:: bash

   pip install scitex-app[all]

Development
-----------

.. code-block:: bash

   git clone git@github.com:ywatanabe1989/scitex-app.git
   cd scitex-app
   pip install -e ".[dev]"
